@@ -4,8 +4,11 @@
 #' convenience, this function labels the layers of a data cube once it has been
 #' loaded with the week dates for each band.
 #'
-#' @param x `RasterStack` or `RasterBrick`; original eBird Status and Trends
-#'   data cube with 52 bands, one for each week.
+#' @param x `RasterStack` or `RasterBrick`; eBird Status and Trends data cube,
+#'   typically with 52 bands, one for each week.
+#' @param weeks vector of dates corresponding to the weeks of each layer in `x`.
+#'   This argument should be used only rarely, when you're labelling a cube with
+#'   fewer that the usual 52 weeks of predictions.
 #'
 #' @return A `RasterStack` or `RasterBrick` with names assigned for the dates in
 #'   the format of "wYYYY.MM.DD" per raster package constraints. The `Raster*`
@@ -17,36 +20,37 @@
 #'
 #' @examples
 #' \dontrun{
-#' # download and load example abundance data
-#' sp_path <- ebirdst_download("example_data")
-#' abd <- load_raster(sp_path, "abundance")
+#' # download example data
+#' path <- ebirdst_download("example_data")
+#' # or get the path if you already have the data downloaded
+#' path <- get_species_path("example_data")
+#'
+#' # weekly relative abundance
+#' # note that only low resolution (lr) data are available for the example data
+#' abd <- load_raster(path, "abundance", resolution = "lr")
 #'
 #' # label
 #' abd <- label_raster_stack(abd)
 #' names(abd)
 #' }
-label_raster_stack <- function(x) {
+label_raster_stack <- function(x, weeks = NULL) {
   stopifnot(inherits(x, "Raster"))
 
-  # check length
-  if((raster::nlayers(x) != 52)) {
-    stop(paste("The input Raster* object must be a full cube of 52",
-               "layers as originally provided."))
+  if (is.null(weeks)) {
+    if((raster::nlayers(x) != 52)) {
+      stop("The input Raster* object must be a full cube of 52 weeks unless ",
+           "a weeks argument is provided to label_raster_stack().")
+    }
+    weeks <- ebirdst::ebirdst_weeks$date
+  }
+  stopifnot(inherits(weeks, "Date"))
+
+  # check lengths
+  if (raster::nlayers(x) != length(weeks)) {
+    stop("The number of raster layers must match the number of weeks.")
   }
 
-  srd_date_vec <- seq(from = 0, to = 1, length.out = 52 + 1)
-  srd_date_vec <- (srd_date_vec[1:52] + srd_date_vec[2:(52 + 1)]) / 2
-  srd_date_vec <- round(srd_date_vec, digits = 4)
-
-  year_seq <- 2015
-  p_time <- strptime(x = paste(round(srd_date_vec * 366), year_seq), "%j %Y")
-  date_names <- paste(paste0("w", ebirdst_version()["data_version"]),
-                      formatC(p_time$mon + 1, width = 2, format = "d",
-                              flag = "0"),
-                      formatC(p_time$mday, width = 2, format = "d",
-                              flag = "0"),
-                      sep = ".")
-
+  date_names <- format(weeks, "w%Y.%m.%d")
   names(x) <- date_names
 
   return(x)
@@ -68,9 +72,14 @@ label_raster_stack <- function(x) {
 #'
 #' @examples
 #' \dontrun{
-#' # download and load example abundance data
-#' sp_path <- ebirdst_download("example_data")
-#' abd <- load_raster(sp_path, "abundance")
+#' # download example data
+#' path <- ebirdst_download("example_data")
+#' # or get the path if you already have the data downloaded
+#' path <- get_species_path("example_data")
+#'
+#' # weekly relative abundance
+#' # note that only low resolution (lr) data are available for the example data
+#' abd <- load_raster(path, "abundance", resolution = "lr")
 #'
 #' # parse dates
 #' parse_raster_dates(abd)
@@ -135,11 +144,7 @@ get_species <- function(x) {
 }
 
 
-# internal functions ----
-
-ebirdst_version <- function() {
-  c(data_version = 2019, release_year = 2020)
-}
+# internal ----
 
 # convert from an iso date to a 0-1 srd date
 to_srd_date <- function(x) {
@@ -153,6 +158,8 @@ to_srd_date <- function(x) {
     } else {
       stop("Input is not a valid date.")
     }
+  } else if (is.numeric(x) || is.integer(x)) {
+    x <- as.Date(paste("2016-", x), format = "%Y-%j")
   } else if (!inherits(x, "Date")) {
     stop("Input is not a valid date.")
   }
@@ -167,7 +174,7 @@ from_srd_date <- function(x, year, iso_date = TRUE) {
   stopifnot(is.logical(iso_date), length(iso_date) == 1)
 
   if (missing(year)) {
-    y <- ebirdst_version()["data_version"]
+    y <- ebirdst_version()[["version_year"]]
   } else {
     y <- year
   }
